Documentation
¶
Overview ¶
Package heartbeat provides requests and response structures to achieve Heartbeat API actions.
Index ¶
- type AddHeartbeatRequest
- type AddHeartbeatResponse
- type DeleteHeartbeatRequest
- type DeleteHeartbeatResponse
- type DisableHeartbeatRequest
- type DisableHeartbeatResponse
- type EnableHeartbeatRequest
- type EnableHeartbeatResponse
- type GetHeartbeatRequest
- type GetHeartbeatResponse
- type Heartbeat
- type HeartbeatData
- type HeartbeatMetaData
- type HeartbeatMetaResponseV2
- type HeartbeatResponseV2
- type ListHeartbeatsRequest
- type ListHeartbeatsResponse
- type PingHeartbeatRequest
- type PingHeartbeatResponse
- type SendHeartbeatRequest
- type SendHeartbeatResponse
- type UpdateHeartbeatRequest
- type UpdateHeartbeatResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AddHeartbeatRequest ¶
type AddHeartbeatRequest struct {
APIKey string `json:"-"`
Name string `json:"name,omitempty"`
Interval int `json:"interval,omitempty"`
IntervalUnit string `json:"intervalUnit,omitempty"`
Description string `json:"description,omitempty"`
Enabled *bool `json:"enabled,omitempty"`
}
AddHeartbeatRequest provides necessary parameter structure to Create an Heartbeat at OpsGenie.
func (*AddHeartbeatRequest) GenerateUrl ¶
func (r *AddHeartbeatRequest) GenerateUrl() (string, url.Values, error)
func (*AddHeartbeatRequest) GetApiKey ¶
func (r *AddHeartbeatRequest) GetApiKey() string
type AddHeartbeatResponse ¶
type AddHeartbeatResponse struct {
Name string `json:"name"`
Status string `json:"status"`
Code int `json:"code"`
}
AddHeartbeatResponse holds the result data of the AddHeartbeatRequest.
type DeleteHeartbeatRequest ¶
DeleteHeartbeatRequest provides necessary parameter structure to Delete an Heartbeat from OpsGenie.
func (*DeleteHeartbeatRequest) GenerateUrl ¶
func (r *DeleteHeartbeatRequest) GenerateUrl() (string, url.Values, error)
func (*DeleteHeartbeatRequest) GetApiKey ¶
func (r *DeleteHeartbeatRequest) GetApiKey() string
type DeleteHeartbeatResponse ¶
DeleteHeartbeatResponse holds the result data of the DeleteHeartbeatRequest.
type DisableHeartbeatRequest ¶
type DisableHeartbeatRequest struct {
APIKey string `json:"-"`
Name string `json:"name,omitempty"`
}
DisableHeartbeatRequest provides necessary parameter structure to Disable an Heartbeat at OpsGenie.
func (*DisableHeartbeatRequest) GenerateUrl ¶
func (r *DisableHeartbeatRequest) GenerateUrl() (string, url.Values, error)
func (*DisableHeartbeatRequest) GetApiKey ¶
func (r *DisableHeartbeatRequest) GetApiKey() string
type DisableHeartbeatResponse ¶
DisableHeartbeatResponse holds the result data of the DisableHeartbeatRequest.
type EnableHeartbeatRequest ¶
EnableHeartbeatRequest provides necessary parameter structure to Enable an Heartbeat at OpsGenie.
func (*EnableHeartbeatRequest) GenerateUrl ¶
func (r *EnableHeartbeatRequest) GenerateUrl() (string, url.Values, error)
func (*EnableHeartbeatRequest) GetApiKey ¶
func (r *EnableHeartbeatRequest) GetApiKey() string
type EnableHeartbeatResponse ¶
EnableHeartbeatResponse holds the result data of the EnableHeartbeatRequest.
type GetHeartbeatRequest ¶
GetHeartbeatRequest provides necessary parameter structure to Retrieve an Heartbeat with details from OpsGenie.
func (*GetHeartbeatRequest) GenerateUrl ¶
func (r *GetHeartbeatRequest) GenerateUrl() (string, url.Values, error)
func (*GetHeartbeatRequest) GetApiKey ¶
func (r *GetHeartbeatRequest) GetApiKey() string
type GetHeartbeatResponse ¶
type GetHeartbeatResponse struct {
Heartbeat
}
GetHeartbeatResponse holds the result data of the GetHeartbeatRequest.
type HeartbeatData ¶
type HeartbeatMetaData ¶
type HeartbeatMetaResponseV2 ¶
type HeartbeatMetaResponseV2 struct {
Code int `json:"code"`
Data HeartbeatMetaData `json:"data"`
Took float32 `json:"took"`
RequestId string `json:"requestId"`
}
func (*HeartbeatMetaResponseV2) SetRateLimitState ¶
func (rm *HeartbeatMetaResponseV2) SetRateLimitState(state string)
func (*HeartbeatMetaResponseV2) SetRequestID ¶
func (rm *HeartbeatMetaResponseV2) SetRequestID(requestID string)
func (*HeartbeatMetaResponseV2) SetResponseTime ¶
func (rm *HeartbeatMetaResponseV2) SetResponseTime(responseTime float32)
type HeartbeatResponseV2 ¶
type HeartbeatResponseV2 struct {
Data HeartbeatData `json:"data"`
Took float32 `json:"took"`
RequestId string `json:"requestId"`
}
func (*HeartbeatResponseV2) SetRateLimitState ¶
func (rm *HeartbeatResponseV2) SetRateLimitState(state string)
func (*HeartbeatResponseV2) SetRequestID ¶
func (rm *HeartbeatResponseV2) SetRequestID(requestID string)
func (*HeartbeatResponseV2) SetResponseTime ¶
func (rm *HeartbeatResponseV2) SetResponseTime(responseTime float32)
type ListHeartbeatsRequest ¶
type ListHeartbeatsRequest struct {
APIKey string `url:"apiKey"`
}
ListHeartbeatsRequest provides necessary parameter structure to Retrieve Heartbeats from OpsGenie.
type ListHeartbeatsResponse ¶
type ListHeartbeatsResponse struct {
Heartbeats []Heartbeat `json:"heartbeats"`
}
ListHeartbeatsResponse holds the result data of the ListHeartbeatsRequest.
type PingHeartbeatRequest ¶
func (*PingHeartbeatRequest) GenerateUrl ¶
func (r *PingHeartbeatRequest) GenerateUrl() (string, url.Values, error)
func (*PingHeartbeatRequest) GetApiKey ¶
func (r *PingHeartbeatRequest) GetApiKey() string
type PingHeartbeatResponse ¶
type SendHeartbeatRequest ¶
type SendHeartbeatRequest struct {
APIKey string `json:"apiKey"`
Name string `json:"name,omitempty"`
}
SendHeartbeatRequest provides necessary parameter structure to Send an Heartbeat Signal to OpsGenie.
type SendHeartbeatResponse ¶
type SendHeartbeatResponse struct {
WillExpireAt uint64 `json:"willExpireAt"`
Status string `json:"status"`
Heartbeat uint64 `json:"heartbeat"`
Took int `json:"took"`
Code int `json:"code"`
}
SendHeartbeatResponse holds the result data of the SendHeartbeatRequest.
type UpdateHeartbeatRequest ¶
type UpdateHeartbeatRequest struct {
APIKey string `json:"-"`
Name string `json:"name,omitempty"`
Interval int `json:"interval,omitempty"`
IntervalUnit string `json:"intervalUnit,omitempty"`
Description string `json:"description,omitempty"`
Enabled *bool `json:"enabled,omitempty"`
}
UpdateHeartbeatRequest provides necessary parameter structure to Update an existing Heartbeat at OpsGenie.
func (*UpdateHeartbeatRequest) GenerateUrl ¶
func (r *UpdateHeartbeatRequest) GenerateUrl() (string, url.Values, error)
func (*UpdateHeartbeatRequest) GetApiKey ¶
func (r *UpdateHeartbeatRequest) GetApiKey() string
type UpdateHeartbeatResponse ¶
type UpdateHeartbeatResponse struct {
Name string `json:"name"`
Status string `json:"status"`
Code int `json:"code"`
}
UpdateHeartbeatResponse holds the result data of the UpdateHeartbeatRequest.