Documentation
¶
Overview ¶
Package policy provides requests and response structures to achieve Policy API actions.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DisablePolicyRequest ¶
type DisablePolicyRequest struct {
APIKey string `json:"apiKey,omitempty"`
ID string `json:"id,omitempty"`
Name string `json:"name,omitempty"`
}
DisablePolicyRequest provides necessary parameter structure to Disable a policy at OpsGenie.
type DisablePolicyResponse ¶
DisablePolicyResponse holds the result data of the DisablePolicyRequest.
type EnablePolicyRequest ¶
type EnablePolicyRequest struct {
APIKey string `json:"apiKey,omitempty"`
ID string `json:"id,omitempty"`
Name string `json:"name,omitempty"`
}
EnablePolicyRequest provides necessary parameter structure to Enable a policy at OpsGenie.
type EnablePolicyResponse ¶
EnablePolicyResponse holds the result data of the EnablePolicyRequest.
Click to show internal directories.
Click to hide internal directories.