Documentation
¶
Overview ¶
Package override provides requests and response structures to achieve Schedule Override API actions.
Index ¶
- type AddScheduleOverrideRequest
- type AddScheduleOverrideResponse
- type DeleteScheduleOverrideRequest
- type DeleteScheduleOverrideResponse
- type GetScheduleOverrideRequest
- type GetScheduleOverrideResponse
- type ListScheduleOverridesRequest
- type ListScheduleOverridesResponse
- type UpdateScheduleOverrideRequest
- type UpdateScheduleOverrideResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AddScheduleOverrideRequest ¶
type AddScheduleOverrideRequest struct {
APIKey string `json:"apiKey,omitempty"`
Alias string `json:"alias,omitempty"`
Schedule string `json:"schedule,omitempty"`
User string `json:"user,omitempty"`
StartDate string `json:"startDate,omitempty"`
EndDate string `json:"endDate,omitempty"`
RotationIds []string `json:"rotationIds,omitempty"`
Timezone string `json:"timezone,omitempty"`
}
AddScheduleOverrideRequest provides necessary parameter structure for adding Schedule Override
type AddScheduleOverrideResponse ¶
type AddScheduleOverrideResponse struct {
Alias string `json:"alias"`
Status string `json:"status"`
Code int `json:"code"`
}
AddScheduleOverrideResponse provides the response structure for adding Schedule Override
type DeleteScheduleOverrideRequest ¶
type DeleteScheduleOverrideRequest struct {
APIKey string `url:"apiKey,omitempty"`
Alias string `url:"alias,omitempty"`
Schedule string `url:"schedule,omitempty"`
}
DeleteScheduleOverrideRequest provides necessary parameter structure for deleting Schedule Override
type DeleteScheduleOverrideResponse ¶
DeleteScheduleOverrideResponse provides the response structure for deleting Schedule Override
type GetScheduleOverrideRequest ¶
type GetScheduleOverrideRequest struct {
APIKey string `url:"apiKey,omitempty"`
Alias string `url:"alias,omitempty"`
Schedule string `url:"schedule,omitempty"`
}
GetScheduleOverrideRequest provides necessary parameter structure for getting Schedule Override
type GetScheduleOverrideResponse ¶
type GetScheduleOverrideResponse struct {
Alias string `json:"alias,omitempty"`
User string `json:"user,omitempty"`
RotationIds []string `json:"rotationIds,omitempty"`
StartDate string `json:"startDate,omitempty"`
EndDate string `json:"endDate,omitempty"`
Timezone string `json:"timezone,omitempty"`
}
GetScheduleOverrideResponse provides the response structure for getting Schedule Override
type ListScheduleOverridesRequest ¶
type ListScheduleOverridesRequest struct {
APIKey string `url:"apiKey,omitempty"`
Schedule string `url:"schedule,omitempty"`
}
ListScheduleOverridesRequest provides necessary parameter structure for listing Schedule Override
type ListScheduleOverridesResponse ¶
type ListScheduleOverridesResponse struct {
Overrides []GetScheduleOverrideResponse `json:"overrides,omitempty"`
}
ListScheduleOverridesResponse provides the response structure for listing Schedule Override
type UpdateScheduleOverrideRequest ¶
type UpdateScheduleOverrideRequest struct {
APIKey string `json:"apiKey,omitempty"`
Alias string `json:"alias,omitempty"`
Schedule string `json:"schedule,omitempty"`
User string `json:"user,omitempty"`
StartDate string `json:"startDate,omitempty"`
EndDate string `json:"endDate,omitempty"`
RotationIds []string `json:"rotationIds,omitempty"`
Timezone string `json:"timezone,omitempty"`
}
UpdateScheduleOverrideRequest provides necessary parameter structure for updating Schedule Override
type UpdateScheduleOverrideResponse ¶
type UpdateScheduleOverrideResponse struct {
Alias string `json:"alias"`
Status string `json:"status"`
Code int `json:"code"`
}
UpdateScheduleOverrideResponse provides the response structure for updating Schedule Override