Documentation
¶
Overview ¶
Package team provides requests and response structures to achieve Team API actions.
Index ¶
- type CreateTeamRequest
- type CreateTeamResponse
- type DeleteTeamRequest
- type DeleteTeamResponse
- type GetTeamRequest
- type GetTeamResponse
- type ListTeamLogsRequest
- type ListTeamLogsResponse
- type ListTeamsRequest
- type ListTeamsResponse
- type Member
- type TeamLogEntry
- type UpdateTeamRequest
- type UpdateTeamResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CreateTeamRequest ¶
type CreateTeamRequest struct {
APIKey string `json:"apiKey,omitempty"`
Description string `json:"description,omitempty"`
Name string `json:"name,omitempty"`
Members []Member `json:"members,omitempty"`
}
CreateTeamRequest provides necessary parameter structure for creating team
type CreateTeamResponse ¶
type CreateTeamResponse struct {
Id string `json:"id"`
Status string `json:"status"`
Code int `json:"code"`
}
Create team response structure
type DeleteTeamRequest ¶
type DeleteTeamRequest struct {
APIKey string `url:"apiKey,omitempty"`
Id string `url:"id,omitempty"`
Name string `url:"name,omitempty"`
}
DeleteTeamRequest provides necessary parameter structure for deleting a team
type DeleteTeamResponse ¶
Delete team response structure
type GetTeamRequest ¶
type GetTeamRequest struct {
APIKey string `url:"apiKey,omitempty"`
Id string `url:"id,omitempty"`
Name string `url:"name,omitempty"`
}
GetTeamRequest provides necessary parameter structure for requesting team information
type GetTeamResponse ¶
type GetTeamResponse struct {
Description string `json:"description,omitempty"`
Id string `json:"id,omitempty"`
Name string `json:"name,omitempty"`
Members []Member `json:"members,omitempty"`
}
Get team response structure
type ListTeamLogsRequest ¶
type ListTeamLogsRequest struct {
APIKey string `url:"apiKey,omitempty"`
Id string `url:"id,omitempty"`
Name string `url:"name,omitempty"`
Limit int `url:"limit,omitempty"`
Order string `url:"order,omitempty"`
LastKey string `url:"lastkey,omitempty"`
}
ListTeamLogsRequest provides necessary parameter structure for listing team logs
type ListTeamLogsResponse ¶
type ListTeamLogsResponse struct {
LastKey string `json:"lastKey,omitempty"`
Logs []TeamLogEntry `json:logs,omitempty`
}
List team logs response structure
type ListTeamsRequest ¶
type ListTeamsRequest struct {
APIKey string `url:"apiKey,omitempty"`
}
ListTeamsRequest provides necessary parameter structure for listing teams
type ListTeamsResponse ¶
type ListTeamsResponse struct {
Teams []GetTeamResponse `json:"teams,omitempty"`
}
List teams response structure
type TeamLogEntry ¶
type TeamLogEntry struct {
Log string `json:"log"`
Owner string `json:"owner"`
CreatedAt uint `json:"createdAt"`
}
A single team log entry
type UpdateTeamRequest ¶
type UpdateTeamRequest struct {
APIKey string `json:"apiKey,omitempty"`
Description string `json:"description,omitempty"`
Id string `json:"id,omitempty"`
Name string `json:"name,omitempty"`
Members []Member `json:"members,omitempty"`
}
UpdateTeamRequest provides necessary parameter structure for updating a team
type UpdateTeamResponse ¶
Update team response structure