Documentation
¶
Overview ¶
Package user provides requests and response structures to achieve User API actions.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CreateUserRequest ¶
type CreateUserRequest struct {
APIKey string `json:"apiKey,omitempty"`
Username string `json:"username,omitempty"`
Fullname string `json:"fullname,omitempty"`
Role string `json:"role,omitempty"`
Locale string `json:"locale,omitempty"`
SkypeUsername string `json:"skypeUsername,omitempty"`
Timezone string `json:"timezone,omitempty"`
}
CreateUserRequest provides necessary parameter structure for creating User
type CreateUserResponse ¶
type CreateUserResponse struct {
Id string `json:"id"`
Status string `json:"status"`
Code int `json:"code"`
}
Create user response structure
type DeleteUserRequest ¶
type DeleteUserRequest struct {
APIKey string `url:"apiKey,omitempty"`
Id string `url:"id,omitempty"`
Username string `url:"username,omitempty"`
}
DeleteUserRequest provides necessary parameter structure for deleting an User
type DeleteUserResponse ¶
Delete user response structure
type GetUserRequest ¶
type GetUserRequest struct {
APIKey string `url:"apiKey,omitempty"`
Id string `url:"id,omitempty"`
Username string `url:"username,omitempty"`
}
GetUserRequest provides necessary parameter structure for requesting User information
type GetUserResponse ¶
type GetUserResponse struct {
Id string `json:"id,omitempty"`
Username string `json:"username,omitempty"`
Fullname string `json:"fullname,omitempty"`
SkypeUsername string `json:"skypeUsername,omitempty"`
Timezone string `json:"timezone,omitempty"`
Locale string `json:"locale,omitempty"`
State string `json:"state,omitempty"`
Escalations []string `json:"escalations,omitempty"`
Schedules []string `json:"schedules,omitempty"`
Role string `json:"role,omitempty"`
Groups []string `json:"groups,omitempty"`
Contacts []Contact `json:"contacts,omitempty"`
}
Get user structure
type ListUsersRequest ¶
type ListUsersRequest struct {
APIKey string `url:"apiKey,omitempty"`
}
ListUserRequest provides necessary parameter structure for listing Users
type ListUsersResponse ¶
type ListUsersResponse struct {
Users []GetUserResponse `json:"users,omitempty"`
}
List user response structure
type UpdateUserRequest ¶
type UpdateUserRequest struct {
Id string `json:"id,omitempty"`
APIKey string `json:"apiKey,omitempty"`
Fullname string `json:"fullname,omitempty"`
Role string `json:"role,omitempty"`
Locale string `json:"locale,omitempty"`
SkypeUsername string `json:"skypeUsername,omitempty"`
Timezone string `json:"timezone,omitempty"`
}
UpdateUserRequest provides necessary parameter structure for updating an User
type UpdateUserResponse ¶
Update user response structure
Click to show internal directories.
Click to hide internal directories.